##  Overview
Collibra EDC (Enterprise Data Catalog) is a data catalog platform and tool that helps organizations better understand and govern their data assets. The integration between SAP LeanIX and Collibra enhances data governance by ensuring alignment and synergy between enterprise architecture and data architecture. With accurate and real-time data, you can make informed decisions regarding data management, application rationalization, technology investments, and compliance initiatives. This integration provides insights into the impact of data policies, regulations, and standards on IT architecture.
This guide provides a comprehensive overview of the integration's benefits, details on what data is synchronized between Collibra and SAP LeanIX, activation instructions, and instructions on how to sync data from Collibra to SAP LeanIX and vice versa.
